@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -6,18 +6,19 @@
 
 #include <gtest/gtest.h>
 
+#ifdef USE_DEEPIN_WAYLAND
 class UT_KeyboardPlantformWayland : public testing::Test
 {
 protected:
     void SetUp() override;
     void TearDown() override;
 
-    KeyboardPlantformWayland *m_keyboard;
+    KeyboardPlatformWayland *m_keyboard;
 };
 
 void UT_KeyboardPlantformWayland::SetUp()
 {
-    m_keyboard = new KeyboardPlantformWayland;
+    m_keyboard = new KeyboardPlatformWayland;
 }
 
 void UT_KeyboardPlantformWayland::TearDown()
@@ -27,7 +28,8 @@ void UT_KeyboardPlantformWayland::TearDown()
 
 TEST_F(UT_KeyboardPlantformWayland, basic)
 {
-    m_keyboard->isCapslockOn();
-    m_keyboard->isNumlockOn();
-    m_keyboard->setNumlockStatus(false);
+    m_keyboard->isCapsLockOn();
+    m_keyboard->isNumLockOn();
+    m_keyboard->setNumLockStatus(false);
 }
+#endif
